@@ -29,7 +29,7 @@ class Database:
             vol_adj_str = 'vol_adj=0' if vol_adj == False else 'vol_adj=1'
             link_str = link_url + code_str + '&' + token_str + '&' + database_str + '&' + start_date_str + '&' + \
                        end_date_str + '&' + freq_str + '&' + price_adj_str + '&' + vol_adj_str
-            
+
             response = requests.get(link_str)
             response_ok = response_check(response)
             if response_ok == True:
@@ -97,7 +97,7 @@ class Database:
                         qfq_df['date'] = pd.to_datetime(qfq_df['date'], format='%Y-%m-%d')
                     else:
                         qfq_df['date'] = pd.to_datetime(qfq_df['date'], format='%Y%m%d')
-                        
+
                     qfq_df = qfq_df.set_index(keys='date')
                     t_index = pd.DatetimeIndex(pd.date_range(start=first_date, end=last_date, freq='1D'))
 
@@ -154,7 +154,7 @@ class Database:
                 df = df[['date', 'time', 'open', 'high', 'low', 'close', 'volume']]
 
                 return df
-    
+
     def get_us_stock_ohlc(self, code, start_date, end_date):
 
         check_bool_dict = self.check_us_stock_ohlc_args(code, start_date, end_date)
@@ -203,8 +203,8 @@ class Database:
                     err_msg += error + ','
             print(err_msg)
 
-    def get_hk_fut_ohlc(self, index, start_date, end_date, freq, rolling_day, rolling_time = 0, rth_only=False):
-        
+    def get_hk_fut_ohlc(self, index, start_date, end_date, freq, rolling_day, rolling_time=0, rth_only=False):
+
         check_bool_dict = self.check_hk_fut_ohlc_args(index, freq, start_date, end_date, rolling_day, rolling_time)
 
         if False not in list(check_bool_dict.values()):
@@ -219,9 +219,14 @@ class Database:
             start_date_dt = datetime.datetime.strptime(str(start_date), '%Y%m%d').date()
             end_date_dt = datetime.datetime.strptime(str(end_date), '%Y%m%d').date()
 
-            start_date_year = start_date_dt.year if start_date_dt.month > 1 else start_date_dt.year - 1
+            if start_date_dt.month > 1:
+                start_date_year = start_date_dt.year
+            else:
+                start_date_year = start_date_dt.year - 1
+                start_date_dt = start_date_dt - relativedelta(months=1)
+
             end_date_year = end_date_dt.year if end_date_dt.month < 11 else end_date_dt.year + 1
-            
+
             holiday_dict = get_hk_holiday_and_expiry_date(start_date_year, end_date_year, 'datetime')
             expiry_date_list = holiday_dict['expiry_date']
 
@@ -242,7 +247,9 @@ class Database:
                 if year_month not in year_month_involved_list:
                     year_month_involved_list.append(year_month)
 
-            year_month_involved_list.append((datetime.datetime.strptime(year_month_involved_list[-1], '%y%m') + relativedelta(months=1)).strftime('%y%m'))
+            year_month_involved_list.append(
+                (datetime.datetime.strptime(year_month_involved_list[-1], '%y%m') + relativedelta(months=1)).strftime(
+                    '%y%m'))
             year_month_involved_list_str = json.dumps(str(year_month_involved_list))
 
             year_month_involved_list_str = year_month_involved_list_str.replace('[', '')
@@ -266,7 +273,6 @@ class Database:
                        + token_str + '&' + database_str + '&' \
                        + start_date_str + '&' + end_date_str
 
-
             response = requests.get(link_str)
             response_ok = response_check(response)
             if response_ok == True:
@@ -291,14 +297,13 @@ class Database:
 
                         date_list = []
                         for temp_date in temp_date_list:
-                            if datetime.datetime.strptime(str(temp_date),'%Y%m%d').weekday() < 5:
+                            if datetime.datetime.strptime(str(temp_date), '%Y%m%d').weekday() < 5:
                                 date_list.append(temp_date)
 
                         front_year_month = str(date_list[0])[2:6]
                         back_year_month = str(date_list[-1])[2:6]
                         front_expiry_date = int(expiry_date_dict[front_year_month].strftime('%Y%m%d'))
                         back_expiry_date = int(expiry_date_dict[back_year_month].strftime('%Y%m%d'))
-
                         for i in range(len(date_list)):
                             date_item = date_list[i]
 
@@ -311,13 +316,16 @@ class Database:
                             else:
                                 back_cut_off_date = max(date_list)
 
-                        if df.loc[0,'expiry_date'] == '20130530':
+                        if df.loc[0, 'expiry_date'] == '20130530':
                             front_cut_off_date = 20130501
 
-                        if (back_cut_off_date != end_date) or (back_cut_off_date == end_date and back_cut_off_date not in expiry_date_list):
+                        if (back_cut_off_date != end_date) or (
+                                back_cut_off_date == end_date and back_cut_off_date not in expiry_date_list):
                             if '1D' not in freq:
-                                df = df[(df['date'] > front_cut_off_date) | ((df['date'] == front_cut_off_date) & (df['time'] >= rolling_time))]
-                                df = df[(df['date'] < back_cut_off_date) | ((df['date'] == back_cut_off_date) & (df['time'] < rolling_time))]
+                                df = df[(df['date'] > front_cut_off_date) | (
+                                            (df['date'] == front_cut_off_date) & (df['time'] >= rolling_time))]
+                                df = df[(df['date'] < back_cut_off_date) | (
+                                            (df['date'] == back_cut_off_date) & (df['time'] < rolling_time))]
                             else:
                                 df = df[(df['date'] > front_cut_off_date) | (df['date'] == front_cut_off_date)]
                                 df = df[(df['date'] < back_cut_off_date) | (df['date'] == back_cut_off_date)]
@@ -354,7 +362,7 @@ class Database:
                         date_time_list_list += date_time_list
 
                 if '1D' not in freq:
-                    cols = ['datetime', 'date', 'time', 'open', 'high', 'low', 'close', 'volume', 'expiry_date','RTH']
+                    cols = ['datetime', 'date', 'time', 'open', 'high', 'low', 'close', 'volume', 'expiry_date', 'RTH']
                 else:
                     cols = ['datetime', 'date', 'open', 'high', 'low', 'close', 'volume', 'expiry_date']
                 df = pd.concat(df_list)
@@ -374,8 +382,8 @@ class Database:
                         if len(check_drop_index_row) > 1:
                             index_0 = check_drop_index_row.index[0]
                             index_1 = check_drop_index_row.index[1]
-                            expiry_date_0 = df.loc[index_0,'expiry_date']
-                            expiry_date_1 = df.loc[index_1,'expiry_date']
+                            expiry_date_0 = df.loc[index_0, 'expiry_date']
+                            expiry_date_1 = df.loc[index_1, 'expiry_date']
                             if expiry_date_0 > expiry_date_1:
                                 drop_index_list.append(index_0)
                             elif expiry_date_0 < expiry_date_1:
@@ -390,10 +398,10 @@ class Database:
                 if '1D' not in freq and rth_only == True:
                     df = df[df['RTH'] == True]
 
-                #df = df.drop_duplicates(keep='last')
+                # df = df.drop_duplicates(keep='last')
 
                 return df
-    
+
         else:
             err_msg = 'Error in: '
             for error in check_bool_dict:
@@ -402,7 +410,7 @@ class Database:
             print(err_msg)
 
     def get_hk_market_cap_hist_by_date(self, start_date, end_date):
-        
+
         check_bool_dict = self.check_start_end_date(start_date, end_date)
 
         if False not in list(check_bool_dict.values()):
@@ -433,7 +441,12 @@ class Database:
 
                 df = df.sort_values(['date', 'market_cap_mil'], ascending=[True, False])
                 df = df.reset_index(drop=True)
-                df['date'] = pd.to_datetime(df['date'],format='%Y-%m-%d')
+
+                if '-' in df.at[0, 'date']:
+                    df['date'] = pd.to_datetime(df['date'], format='%Y-%m-%d')
+                else:
+                    df['date'] = pd.to_datetime(df['date'], format='%Y%m%d')
+
                 df = df[['date','code','issued_share_mil','market_cap_mil','cumulative_market_cap_mil']]
                 return df
 
@@ -445,7 +458,7 @@ class Database:
             print(err_msg)
 
     def get_hk_market_cap_hist_by_code(self, code):
-        
+
         check_bool_dict = self.check_hk_code_args(code)
 
         if False not in list(check_bool_dict.values()):
@@ -454,7 +467,7 @@ class Database:
             database_str = 'database=' + 'hk_market_cap_hist_by_code'
             code_str = 'code=' + str(code)
             link_str = link_url + '&' + token_str + '&' + database_str + '&' + code_str
-            
+
             response = requests.get(link_str)
             response_ok = response_check(response)
             if response_ok == True:
@@ -474,7 +487,10 @@ class Database:
 
                 df = df.sort_values(by='date')
                 df = df.reset_index(drop=True)
-                df['date'] = pd.to_datetime(df['date'],format='%Y-%m-%d')
+                if '-' in df.at[0, 'date']:
+                    df['date'] = pd.to_datetime(df['date'], format='%Y-%m-%d')
+                else:
+                    df['date'] = pd.to_datetime(df['date'], format='%Y%m%d')
                 df = df[['date','code','issued_share_mil','market_cap_mil','cumulative_market_cap_mil']]
                 df = df.set_index('date')
                 df = df[~df.index.duplicated(keep='first')]
@@ -495,7 +511,7 @@ class Database:
         database_str = 'database=' + 'hk_buyback_by_code'
         code_str = 'code=' + code
         link_str = link_url + code_str + '&' + token_str + '&' + database_str
-        
+
         response = requests.get(link_str)
         response_ok = response_check(response)
         if response_ok == True:
@@ -525,7 +541,7 @@ class Database:
             start_date_str = 'start_date=' + str(start_date)
             end_date_str = 'end_date=' + str(end_date)
             link_str = link_url + '&' + token_str + '&' + database_str + '&' + start_date_str + '&' + end_date_str
-            
+
             response = requests.get(link_str)
             response_ok = response_check(response)
             if response_ok == True:
@@ -656,7 +672,7 @@ class Database:
             start_date_str = 'start_date=' + str(start_date)
             end_date_str = 'end_date=' + str(end_date)
             link_str = link_url + '&' + token_str + '&' + database_str + '&' + start_date_str + '&' + end_date_str
-            
+
             response = requests.get(link_str)
             response_ok = response_check(response)
             if response_ok == True:
@@ -693,7 +709,7 @@ class Database:
         database_str = 'database=' + 'us_earning_calendar_by_code'
         code_str = 'code=' + code
         link_str = link_url + code_str + '&' + token_str + '&' + database_str
-        
+
         response = requests.get(link_str)
         response_ok = response_check(response)
         if response_ok == True:
@@ -708,7 +724,7 @@ class Database:
             return date_list
 
     def get_us_earning_calendar_by_date(self, start_date, end_date):
-        
+
         check_bool_dict = self.check_start_end_date(start_date, end_date)
 
         if False not in list(check_bool_dict.values()):
@@ -718,7 +734,7 @@ class Database:
             start_date_str = 'start_date=' + str(start_date)
             end_date_str = 'end_date=' + str(end_date)
             link_str = link_url + '&' + token_str + '&' + database_str + '&' + start_date_str + '&' + end_date_str
-            
+
             response = requests.get(link_str)
             response_ok = response_check(response)
             if response_ok == True:
@@ -760,7 +776,7 @@ class Database:
             start_date_str = 'start_date=' + str(start_date)
             end_date_str = 'end_date=' + str(end_date)
             link_str = link_url + code_str + '&' + token_str + '&' + database_str + '&' + start_date_str + '&' + end_date_str
-            
+
             response = requests.get(link_str)
             response_ok = response_check(response)
             if response_ok == True:
@@ -793,7 +809,7 @@ class Database:
                 if check_bool_dict[error] == False:
                     err_msg += error + ','
             print(err_msg)
-            
+
     def get_ccass_holding_rank(self, code, start_date, end_date):
 
         check_bool_dict = self.check_ccass_holding_rank_args(code, start_date, end_date)
@@ -1024,12 +1040,16 @@ class Database:
                     df.at[i,'end_date'] = datetime.datetime.now().strftime('%Y-%m-%d')
             for col in df.columns:
                 if col == 'start_date' or col == 'end_date':
-                    df[col] = pd.to_datetime(df[col], format='%Y-%m-%d')
+                    if '-' in df.at[0, col]:
+                        df[col] = pd.to_datetime(df[col], format='%Y-%m-%d')
+                    else:
+                        df[col] = pd.to_datetime(df[col], format='%Y%m%d')
+
 
         return df
-    
+
     def get_hk_index_const(self, index_name, sort_mkt_cap = False):
-        
+
         if len(index_name) > 0:
 
             link_url = 'http://www.hkfdb.net/data_api?'
@@ -1037,7 +1057,7 @@ class Database:
             database_str = 'database=' + 'hk_index_const'
             index_name_str = 'index_name=' + index_name
             link_str = link_url + index_name_str + '&' + token_str + '&' + database_str
-            
+
             response = requests.get(link_str)
             response_ok = response_check(response)
 
@@ -1050,7 +1070,10 @@ class Database:
 
                 for col in df.columns:
                     if col == 'start_date' or col == 'end_date':
-                        df[col] = pd.to_datetime(df[col], format='%Y-%m-%d')
+                        if '-' in df.at[0, col]:
+                            df[col] = pd.to_datetime(df[col], format='%Y-%m-%d')
+                        else:
+                            df[col] = pd.to_datetime(df[col], format='%Y%m%d')
 
                 if index_name == 'hsi_const_hist':
 
@@ -1061,11 +1084,16 @@ class Database:
                         end_date = df.loc[i, 'end_date']
                         is_active = df.loc[i, 'is_active']
                         if is_active == True:
+
                             df.at[i, 'end_date'] = datetime.datetime.now().strftime('%Y-%m-%d')
 
                     for col in df.columns:
                         if col == 'start_date' or col == 'end_date':
-                            df[col] = pd.to_datetime(df[col], format='%Y-%m-%d')
+                            if '-' in df.at[0, col]:
+                                df[col] = pd.to_datetime(df[col], format='%Y-%m-%d')
+                            else:
+                                df[col] = pd.to_datetime(df[col], format='%Y%m%d')
+
                     df = df[['code','name','start_date','end_date','is_active']]
 
                 if sort_mkt_cap:
@@ -1079,9 +1107,9 @@ class Database:
         else:
             err_msg =  'index_name missing'
             print(err_msg)
-            
+
     def get_hk_stock_plate_const(self, plate_name):
-        
+
         if len(plate_name) > 0:
 
             link_url = 'http://www.hkfdb.net/data_api?'
@@ -1089,7 +1117,7 @@ class Database:
             database_str = 'database=' + 'hk_stock_plate_const'
             plate_name_str = 'plate_name=' + plate_name
             link_str = link_url + plate_name_str + '&' + token_str + '&' + database_str
-            
+
             response = requests.get(link_str)
             response_ok = response_check(response)
             if response_ok == True:
@@ -1105,15 +1133,15 @@ class Database:
         else:
             err_msg =  'index_name missing'
             print(err_msg)
-            
-        
+
+
     def get_all_hk_index_name(self):
 
         link_url = 'http://www.hkfdb.net/data_api?'
         token_str = 'token=' + str(self.authToken)
         database_str = 'database=' + 'all_hk_index_name'
         link_str = link_url + '&' + token_str + '&' + database_str
-        
+
         response = requests.get(link_str)
         response_ok = response_check(response)
         if response_ok == True:
@@ -1132,7 +1160,7 @@ class Database:
         token_str = 'token=' + str(self.authToken)
         database_str = 'database=' + 'all_hk_stock_plate_name'
         link_str = link_url + '&' + token_str + '&' + database_str
-        
+
         response = requests.get(link_str)
         response_ok = response_check(response)
 
@@ -1150,7 +1178,7 @@ class Database:
         token_str = 'token=' + str(self.authToken)
         database_str = 'database=' + 'basic_hk_stock_info'
         link_str = link_url + '&' + token_str + '&' + database_str
-        
+
         response = requests.get(link_str)
         response_ok = response_check(response)
         if response_ok == True:
@@ -1169,7 +1197,10 @@ class Database:
 
             df = pd.DataFrame(result)
 
-            df['ipo_date'] = pd.to_datetime(df['ipo_date'],format='%Y-%m-%d')
+            if '-' in df.at[0, 'ipo_date']:
+                df['ipo_date'] = pd.to_datetime(df['ipo_date'], format='%Y-%m-%d')
+            else:
+                df['ipo_date'] = pd.to_datetime(df['ipo_date'], format='%Y%m%d')
 
             df['share_issued'] = df['share_issued'].astype(str)
             df['share_issued'] = df['share_issued'].str.replace('-','', regex=False)
@@ -1182,7 +1213,8 @@ class Database:
             df = df.sort_values(by='code')
 
             df['market_capital'] = df['market_capital'].astype('int64')
-            df['is_stop_trading'] = df['is_stop_trading'].map({'1': True, '0': False})
+            df['is_stop_trading'] = df['is_stop_trading'].map({'True': True, 'False': False})
+            df = df.rename(columns={'is_stop_trading':'stop_trading'})
 
             float_col_list = ['price','PE','EPS','dividend']
             int_col_list = ['volume','turnover']
@@ -1196,7 +1228,7 @@ class Database:
                 df[col] = df[col].astype('int64')
             df['lot_size'] = df['lot_size'].astype(int)
 
-            df = df[['code','stock_name','price','PE','EPS','dividend','volume','turnover','share_issued','lot_size','market_capital','ipo_date','year_end_date', 'is_stop_trading','category']]
+            df = df[['code','stock_name','price','PE','EPS','dividend','volume','turnover','share_issued','lot_size','market_capital','ipo_date','year_end_date', 'stop_trading','category']]
             return df
 
     def get_hk_ipo_hist(self):
@@ -1205,7 +1237,7 @@ class Database:
         token_str = 'token=' + str(self.authToken)
         database_str = 'database=' + 'hk_ipo_hist'
         link_str = link_url + '&' + token_str + '&' + database_str
-        
+
         response = requests.get(link_str)
         response_ok = response_check(response)
         if response_ok == True:
@@ -1238,9 +1270,9 @@ class Database:
             return df
 
     def get_market_highlight(self, start_date, end_date):
-        
+
         market = 'hk_main_board'
-        
+
         check_bool_dict = self.check_market_highlight_args(market, start_date, end_date)
 
         if False not in list(check_bool_dict.values()):
@@ -1252,7 +1284,7 @@ class Database:
             end_date_str = 'end_date=' + str(end_date)
             link_str = link_url + market_str + '&' + token_str + '&' + database_str + '&' + start_date_str + '&' + \
                        end_date_str
-            
+
             response = requests.get(link_str)
             response_ok = response_check(response)
             if response_ok == True:
@@ -1296,7 +1328,7 @@ class Database:
             end_date_str = 'end_date=' + str(end_date)
             link_str = link_url + '&' + token_str + '&' + database_str + '&' + start_date_str + '&' + \
                        end_date_str
-            
+
             response = requests.get(link_str)
             response_ok = response_check(response)
             if response_ok == True:
@@ -1348,7 +1380,7 @@ class Database:
             link_str = link_url + '&' + token_str + '&' + database_str \
                        + '&' + start_date_str + '&' + end_date_str\
                        + '&' + deri_str  + '&' + code_str  + '&' + exp_str
-            
+
             response = requests.get(link_str)
             response_ok = response_check(response)
             if response_ok == True:
@@ -1356,6 +1388,7 @@ class Database:
                 result = json.loads(json.loads(response.content).replace("'", "\""))
 
                 df_list = []
+
                 for item in result:
                     date_int = item['_id']
                     df = pd.DataFrame(item['content'])
@@ -1427,26 +1460,28 @@ class Database:
 
                 result_list = json.loads(json.loads(response.content).replace("'", "\""))
 
-                columns = ['cbbc_code', 'cbbc_name', 'date', 'num_of_cbbc_bought', 'avg_price_per_cbbc_bought',
-                           'num_of_cbbc_sold', 'avg_price_per_cbbc_sold', 'num_of_cbbc_in_mkt', 'pct_of_issued_in_mkt',
-                           'total_issued_size', 'currency', 'day_high', 'day_low', 'close_price', 'volume', 'turnover',
-                           'issuer', 'underlying', 'bull_bear', 'cbbc_type', 'cbbc_category', 'listing_date',
-                           'last_trading_date', 'maturity_date', 'mce', 'strike_or_call_currency', 'strike_level',
-                           'call_level', 'entitlement_ratio', 'delisting_date']
+                columns = ['unique_id', 'cbbc_code', 'cbbc_name', 'date', 'num_of_cbbc_bought',
+                           'avg_price_per_cbbc_bought',
+                           'num_of_cbbc_sold', 'avg_price_per_cbbc_sold', 'num_of_cbbc_in_mkt', 'total_issued_size',
+                           'currency', 'issuer', 'underlying', 'bull_bear', 'listing_date', 'strike_or_call_currency',
+                           'strike_level', 'call_level', 'entitlement_ratio']
 
                 df_list = []
                 for result in result_list:
                     for item, content in result.items():
                         if type(content) is list:
                             df = pd.DataFrame(content, columns=columns)
-                            df['date'] = df['date'] / 1000000000
-                            df['date'] = pd.to_datetime(df['date'], unit='s')
+                            df['date'] = pd.to_datetime(df['date'], format='%Y%m%d')
+                            df['listing_date'] = pd.to_datetime(df['listing_date'], format='%Y%m%d')
                             df_list.append(df)
 
                 df = pd.concat(df_list)
                 df = df.sort_values('date')
-                df = df.reset_index()
-                df = df.drop('index', axis=1)
+                df['num_of_cbbc_sold'] = df['num_of_cbbc_sold'].abs()
+                df['avg_price_per_cbbc_sold'] = df['avg_price_per_cbbc_sold'].abs()
+                df['bull_bear'] = df['bull_bear'].str.replace(' ','')
+                df = df.set_index('unique_id')
+                # df = df.drop('index', axis=1)
 
                 return df
 
@@ -1456,7 +1491,7 @@ class Database:
                 if check_bool_dict[error] == False:
                     err_msg += error + ','
             print(err_msg)
-            
+
     #########################################################################################
 
     def check_hk_stock_ohlc_args(self, code, start_date, end_date, freq):
@@ -1504,7 +1539,7 @@ class Database:
                                    datetime.datetime.strptime(str(start_date), '%Y%m%d').date()
         except:
             end_after_start_date = False
-        
+
         check_bool_dict = {'freq_valid': freq_valid,
                            'code_isdigit': code_isdigit,
                            'code_length': code_length,
@@ -1515,7 +1550,7 @@ class Database:
                            'end_date_length': end_date_length,
                            #'end_date_future': end_date_future,
                            'end_after_start_date': end_after_start_date}
-        
+
         return check_bool_dict
     def check_us_stock_ohlc_args(self, code, start_date, end_date):
 
@@ -1556,8 +1591,8 @@ class Database:
                 str(start_date), '%Y%m%d').date()
         except:
             end_after_start_date = False
-        
-        
+
+
         check_bool_dict = {'code_length': code_length,
                            'start_date_length': start_date_length,
                            'start_date_is_int': start_date_is_int,
@@ -1566,7 +1601,7 @@ class Database:
                            'end_date_length': end_date_length,
                            #'end_date_future': end_date_future,
                            'end_after_start_date': end_after_start_date}
-        
+
         return check_bool_dict
 
     def check_hk_fut_ohlc_args(self, index, freq, start_date, end_date, rolling_day, rolling_time):
@@ -1720,7 +1755,7 @@ class Database:
                 str(start_date), '%Y%m%d').date()
         except:
             end_after_start_date = False
-        
+
         check_bool_dict = {
             'start_date_length': start_date_length,
             'start_date_is_int': start_date_is_int,
@@ -1729,7 +1764,7 @@ class Database:
             'end_date_length': end_date_length,
             #'end_date_future': end_date_future,
             'end_after_start_date': end_after_start_date}
-        
+
         return check_bool_dict
 
     def check_ccass_by_id_args(self, ccass_id, start_date, end_date):
@@ -1767,8 +1802,8 @@ class Database:
                 str(start_date), '%Y%m%d').date()
         except:
             end_after_start_date = False
-        
-        
+
+
         check_bool_dict = {'ccass_id_len' : ccass_id_len,
                            'start_date_length': start_date_length,
                            'start_date_is_int': start_date_is_int,
@@ -1778,7 +1813,7 @@ class Database:
                            #'end_date_future': end_date_future,
                            'end_after_start_date': end_after_start_date}
         return check_bool_dict
-    
+
     def check_ccass_by_code_args(self, code, start_date, end_date):
 
         try:
@@ -1821,8 +1856,8 @@ class Database:
                 str(start_date), '%Y%m%d').date()
         except:
             end_after_start_date = False
-        
-        
+
+
         check_bool_dict = {
             'code_isdigit': code_isdigit,
             'code_length': code_length,
@@ -1833,7 +1868,7 @@ class Database:
             'end_date_length': end_date_length,
             #'end_date_future': end_date_future,
             'end_after_start_date': end_after_start_date}
-        
+
         return check_bool_dict
     def check_ccass_holding_rank_args(self, code, start_date, end_date):
 
@@ -1878,7 +1913,7 @@ class Database:
                 str(start_date), '%Y%m%d').date()
         except:
             end_after_start_date = False
-        
+
 
         check_bool_dict = {
             'code_isdigit': code_isdigit,
@@ -1945,8 +1980,8 @@ class Database:
                 str(start_date), '%Y%m%d').date()
         except:
             end_after_start_date = False
-        
-        
+
+
         check_bool_dict = {'code_length': code_length,
                            'start_date_length': start_date_length,
                            'start_date_is_int': start_date_is_int,
